"use strict";
// Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license.
// See LICENSE in the project root for license information.
Object.defineProperty(exports, "__esModule", { value: true });
const node_fs_1 = require("node:fs");
const node_path_1 = require("node:path");
const Async_1 = require("@rushstack/node-core-library/lib/Async");
const binding_1 = require("@swc/core/binding");
const [buildFolderPath, concurrency] = process.argv.slice(-2);
if (!buildFolderPath) {
    throw new Error(`buildFolderPath argument not provided to child_process`);
}
const handleMessageAsync = async (message) => {
    if (!message) {
        process.off('message', handleMessageAsync);
        return;
    }
    const groupStart = performance.now();
    const { tasks, options } = message;
    const optionsBuffers = options.map((option) => Buffer.from(option));
    const timings = [];
    const errors = [];
    const createdFolders = new Set();
    function createFolder(folderPath) {
        if (!createdFolders.has(folderPath)) {
            (0, node_fs_1.mkdirSync)(`${buildFolderPath}/${folderPath}`, { recursive: true });
            createdFolders.add(folderPath);
            let slashIndex = folderPath.lastIndexOf('/');
            while (slashIndex >= 0) {
                folderPath = folderPath.slice(0, slashIndex);
                createdFolders.add(folderPath);
                slashIndex = folderPath.lastIndexOf('/');
            }
        }
    }
    await Async_1.Async.forEachAsync(tasks, async (task) => {
        var _a;
        const { srcFilePath, relativeSrcFilePath, optionsIndex, jsFilePath, mapFilePath } = task;
        let result;
        const start = performance.now();
        try {
            result = await (0, binding_1.transformFile)(srcFilePath, true, optionsBuffers[optionsIndex]);
        }
        catch (error) {
            errors.push([jsFilePath, (_a = error.stack) !== null && _a !== void 0 ? _a : error.toString()]);
            return;
        }
        finally {
            const end = performance.now();
            timings.push([jsFilePath, end - start]);
        }
        if (result) {
            createFolder((0, node_path_1.dirname)(jsFilePath));
            let { code, map } = result;
            if (mapFilePath && map) {
                code += `\n//# sourceMappingURL=./${(0, node_path_1.basename)(mapFilePath)}`;
                const parsedMap = JSON.parse(map);
                parsedMap.sources[0] = relativeSrcFilePath;
                map = JSON.stringify(parsedMap);
                (0, node_fs_1.writeFileSync)(`${buildFolderPath}/${mapFilePath}`, map, 'utf8');
            }
            (0, node_fs_1.writeFileSync)(`${buildFolderPath}/${jsFilePath}`, code, 'utf8');
        }
    }, {
        concurrency: parseInt(concurrency, 10)
    });
    const groupEnd = performance.now();
    const result = {
        errors,
        timings,
        durationMs: groupEnd - groupStart
    };
    if (!process.send) {
        throw new Error(`process.send is not available in process`);
    }
    process.send(result);
};
process.on('message', handleMessageAsync);
//# sourceMappingURL=TranspileWorker.js.map